==> subscriptionlib-0.1.tar.gz: subscriptionlib-0.1/subscriptionlib/setup.py <==
from distutils.core import setup
setup(
  name = 'subscriptionlib',         # How you named your package folder (MyLib)
  packages = ['subscriptionlib'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Subscription verification layer for Acta',   # Give a short description about your library
  author = 'Cedric Chalhoub @ Metaflow',                   # Type in your name
  author_email = 'cedric.chalhoub@metaflow.ca',      # Type in your E-Mail
  url = 'https://github.com/cedric-at-metaflow/subscriptionlib',   # Provide either the link to your github or to your website
  download_url='https://github.com/cedric-at-metaflow/subscriptionlib/archive/refs/tags/v_01.tar.gz',
  keywords = ['Zoho Subscriptions', 'Subscriptions', 'Customer'],   # Keywords that define your package best
  install_requires=[
    'requests'
  ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
  ],
)

==> subscriptionlib-0.2.tar.gz: subscriptionlib-0.2/subscriptionlib/setup.py <==
from distutils.core import setup
setup(
  name = 'subscriptionlib',         # How you named your package folder (MyLib)
  packages = ['subscriptionlib'],   # Chose the same as "name"
  version = '0.2',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Subscription verification layer for Acta',   # Give a short description about your library
  author = 'Cedric Chalhoub @ Metaflow',                   # Type in your name
  author_email = 'cedric.chalhoub@metaflow.ca',      # Type in your E-Mail
  url = 'https://github.com/cedric-at-metaflow/subscriptionlib',   # Provide either the link to your github or to your website
  download_url='https://github.com/cedric-at-metaflow/subscriptionlib/archive/refs/tags/0.2.tar.gz',
  keywords = ['Zoho Subscriptions', 'Subscriptions', 'Customer'],   # Keywords that define your package best
  install_requires=[
    'requests'
  ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
  ],
)
